@@ -4,7 +4,9 @@ import enum
 class Action(enum.Enum):
     """Turbo-Stream action parameter"""
 
+    AFTER = "after"
     APPEND = "append"
+    BEFORE = "before"
     PREPEND = "prepend"
     REMOVE = "remove"
     REPLACE = "replace"
